==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/UNMATCHEDINVOICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour UNMATCHEDINVOICEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="UNMATCHEDINVOICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UNMATCHEDINVOICEID_Type", propOrder = {
    "invoiceid",
    "line",
    "description"
})
public class UNMATCHEDINVOICEID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "LINE")
    protected Long line;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété invoiceid.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Définit la valeur de la propriété invoiceid.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Obtient la valeur de la propriété line.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getLINE() {
        return line;
    }

    /**
     * Définit la valeur de la propriété line.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setLINE(Long value) {
        this.line = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/UNMATCHEDINVOICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for UNMATCHEDINVOICEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="UNMATCHEDINVOICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UNMATCHEDINVOICEID_Type", propOrder = {
    "invoiceid",
    "line",
    "description"
})
public class UNMATCHEDINVOICEID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "LINE")
    protected Long line;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the invoiceid property.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Sets the value of the invoiceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Gets the value of the line property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getLINE() {
        return line;
    }

    /**
     * Sets the value of the line property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setLINE(Long value) {
        this.line = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
